==> kubernetes-model-storageclass-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/storage/CSINodeDriverBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSINodeDriverBuilder extends io.fabric8.kubernetes.api.model.storage.CSINodeDriverFluentImpl<io.fabric8.kubernetes.api.model.storage.CSINodeDriverBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.CSINodeDriver,io.fabric8.kubernetes.api.model.storage.CSINodeDriverBuilder>{
  public CSINodeDriverBuilder() {
    this(false);
  }
  public CSINodeDriverBuilder(java.lang.Boolean validationEnabled) {
    this(new CSINodeDriver(), validationEnabled);
  }
  public CSINodeDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSINodeDriverFluent<?> fluent) {
    this(fluent, false);
  }
  public CSINodeDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSINodeDriverFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSINodeDriver(), validationEnabled);
  }
  public CSINodeDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSINodeDriverFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.CSINodeDriver instance) {
    this(fluent, instance, false);
  }
  public CSINodeDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSINodeDriverFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.CSINodeDriver instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllocatable(instance.getAllocatable()); 
    fluent.withName(instance.getName()); 
    fluent.withNodeID(instance.getNodeID()); 
    fluent.withTopologyKeys(instance.getTopologyKeys()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSINodeDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSINodeDriver instance) {
    this(instance,false);
  }
  public CSINodeDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSINodeDriver instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllocatable(instance.getAllocatable()); 
    this.withName(instance.getName()); 
    this.withNodeID(instance.getNodeID()); 
    this.withTopologyKeys(instance.getTopologyKeys()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.CSINodeDriverFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.CSINodeDriver build() {
    CSINodeDriver buildable = new CSINodeDriver(fluent.getAllocatable(),fluent.getName(),fluent.getNodeID(),fluent.getTopologyKeys());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSINodeDriverBuilder that = (CSINodeDriverBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/storage/CSINodeDriverBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CSINodeDriverBuilder extends CSINodeDriverFluentImpl<CSINodeDriverBuilder> implements VisitableBuilder<CSINodeDriver,CSINodeDriverBuilder>{
  public CSINodeDriverBuilder() {
    this(false);
  }
  public CSINodeDriverBuilder(Boolean validationEnabled) {
    this(new CSINodeDriver(), validationEnabled);
  }
  public CSINodeDriverBuilder(CSINodeDriverFluent<?> fluent) {
    this(fluent, false);
  }
  public CSINodeDriverBuilder(CSINodeDriverFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CSINodeDriver(), validationEnabled);
  }
  public CSINodeDriverBuilder(CSINodeDriverFluent<?> fluent,CSINodeDriver instance) {
    this(fluent, instance, false);
  }
  public CSINodeDriverBuilder(CSINodeDriverFluent<?> fluent,CSINodeDriver instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllocatable(instance.getAllocatable()); 
    fluent.withName(instance.getName()); 
    fluent.withNodeID(instance.getNodeID()); 
    fluent.withTopologyKeys(instance.getTopologyKeys()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSINodeDriverBuilder(CSINodeDriver instance) {
    this(instance,false);
  }
  public CSINodeDriverBuilder(CSINodeDriver instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllocatable(instance.getAllocatable()); 
    this.withName(instance.getName()); 
    this.withNodeID(instance.getNodeID()); 
    this.withTopologyKeys(instance.getTopologyKeys()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CSINodeDriverFluent<?> fluent;
  Boolean validationEnabled;
  public CSINodeDriver build() {
    CSINodeDriver buildable = new CSINodeDriver(fluent.getAllocatable(),fluent.getName(),fluent.getNodeID(),fluent.getTopologyKeys());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
